==> cftp_0.9.orig.tar.gz: cftp-0.9/fntable.c <==
/*
   This file is automatically created from ``fntable.fn''; don't change
   this file, change ``fntable.fn'' instead.
*/

#include "directory.h"
#include "bindings.h"
#include "functions.h"
#include "fntable.h"

function functions[] = {
/* Basic Functions: fn_basic */
  0 , "exit", FN_EXIT, "exit cftp" ,
  fn_version , "version", 0, "display version number" ,
  fn_redraw , "redraw", FN_PRE, "redraw screen" ,
  fn_showname , "show-name", 0, "show name of file under cursor" ,
  fn_help , "help", 0, "display help" ,
  fn_lcd , "lcd", FN_RC, "change directory on local host" ,
  fn_shell , "shell", 0, "shell escape" ,
  fn_colon , "colon", 0, "execute cftp command" ,
  fn_deidle , "deidle", 0, "deidle connection" ,
  fn_reconnect , "reconnect", 0, "reconnect to server" ,
  fn_response , "response", 0, "display dialog with server" ,
  fn_prefix , "prefix", FN_PRE, "prefix digit" ,
  fn_bind , "bind", FN_RC, "bind key" ,
  fn_set , "set", FN_RC, "set option" ,
/* Scrolling Functions: fn_scroll */
  fn_down , "down", 0, "move cursor N lines down (default: 1)" ,
  fn_up , "up", 0, "move cursor N lines up (default: 1)" ,
  fn_pg_down , "page-down", 0, "move N screens down (default: 1)" ,
  fn_pg_up , "page-up", 0, "move N screens up (default: 1)" ,
  fn_goto , "goto", 0, "goto line N (default: last)" ,
  fn_isearch , "isearch", 0, "incremental search" ,
/* Selection Functions: fn_select */
  fn_enter_get , "enter/get", 0, "enter directory or get file" ,
  fn_enter_view , "enter/view", 0, "enter directory or view file" ,
  fn_enter , "enter", 0, "enter directory" ,
  fn_reload , "reload", 0, "reload current directory" ,
  fn_get , "get", 0, "get file" ,
  fn_view , "view", 0, "view file" ,
  fn_pipe , "pipe", 0, "pipe file to command" ,
  fn_put , "put", 0, "put file" ,
  fn_cdup , "leave", 0, "leave current directory" ,
  fn_cd , "cd", 0, "change directory" ,
  fn_state , "state", 0, "change binding state" ,
  fn_leave_tag , "leave-tag", 0, "leave @code{<tag>} state" ,
/* Tagging Functions: fn_tag */
  fn_tag , "tag", 0, "tag/untag file for later download" ,
  fn_cleartags , "clear-tags", 0, "clear all tags" ,
  fn_gettags , "get-tags", 0, "get tagged files" ,
  fn_savetags , "save-tags", 0, "save tag list to file" ,
  fn_loadtag , "load-tags", 0, "load tag list from file" ,
  fn_saveurls , "save-urls", 0, "save tags as url list" ,
/* end marker */
  { 0, 0, 0, 0 }
};

==> cftp_0.10.orig.tar.gz: cftp-0.10/fntable.c <==
/*
   This file is automatically created from ``fntable.fn''; don't change
   this file, change ``fntable.fn'' instead.
*/

#include "directory.h"
#include "bindings.h"
#include "functions.h"
#include "fntable.h"

function functions[] = {
/* Basic Functions: fn_basic */
  0 , "exit", FN_EXIT, "exit cftp" ,
  fn_version , "version", 0, "display version number" ,
  fn_redraw , "redraw", FN_PRE, "redraw screen" ,
  fn_showname , "show-name", 0, "show name of file under cursor" ,
  fn_help , "help", 0, "display help" ,
  fn_lcd , "lcd", FN_RC, "change directory on local host" ,
  fn_shell , "shell", 0, "shell escape" ,
  fn_colon , "colon", 0, "execute cftp command" ,
  fn_deidle , "deidle", 0, "deidle connection" ,
  fn_site , "site", 0, "send site specific command" ,
  fn_reconnect , "reconnect", 0, "reconnect to server" ,
  fn_response , "response", 0, "display dialog with server" ,
  fn_mkdir , "mkdir", 0, "create directory on server" ,
  fn_prefix , "prefix", FN_PRE, "prefix digit" ,
  fn_bind , "bind", FN_RC, "bind key" ,
  fn_set , "set", FN_RC, "set option" ,
/* Scrolling Functions: fn_scroll */
  fn_down , "down", 0, "move cursor N lines down (default: 1)" ,
  fn_up , "up", 0, "move cursor N lines up (default: 1)" ,
  fn_pg_down , "page-down", 0, "move N screens down (default: 1)" ,
  fn_pg_up , "page-up", 0, "move N screens up (default: 1)" ,
  fn_goto , "goto", 0, "goto line N (default: last)" ,
  fn_isearch , "isearch", 0, "incremental search" ,
/* Selection Functions: fn_select */
  fn_enter_get , "enter/get", 0, "enter directory or get file" ,
  fn_enter_view , "enter/view", 0, "enter directory or view file" ,
  fn_enter , "enter", 0, "enter directory" ,
  fn_reload , "reload", 0, "reload current directory" ,
  fn_get , "get", 0, "get file" ,
  fn_view , "view", 0, "view file" ,
  fn_pipe , "pipe", 0, "pipe file to command" ,
  fn_put , "put", 0, "put file" ,
  fn_cdup , "leave", 0, "leave current directory" ,
  fn_cd , "cd", 0, "change directory" ,
  fn_state , "state", 0, "change binding state" ,
  fn_leave_tag , "leave-tag", 0, "leave @code{<tag>} state" ,
/* Tagging Functions: fn_tag */
  fn_tag , "tag", 0, "tag/untag file for later download" ,
  fn_cleartags , "clear-tags", 0, "clear all tags" ,
  fn_gettags , "get-tags", 0, "get tagged files" ,
  fn_savetags , "save-tags", 0, "save tag list to file" ,
  fn_loadtag , "load-tags", 0, "load tag list from file" ,
  fn_saveurls , "save-urls", 0, "save tags as url list" ,
/* end marker */
  { 0, 0, 0, 0 }
};
